# Specs

## SpecCache

::: aitaem.specs.loader.SpecCache

---

## MetricSpec

::: aitaem.specs.metric.MetricSpec

---

## SliceSpec

::: aitaem.specs.slice.SliceSpec

---

## SliceValue

::: aitaem.specs.slice.SliceValue

---

## SegmentSpec

::: aitaem.specs.segment.SegmentSpec

---

## SegmentValue

::: aitaem.specs.segment.SegmentValue
